Welcome to ClientVPS Mirrors

Help for package ChernoffDist
Type: Package
Title: Chernoff's Distribution
Version: 0.1.0
Author: Haitian Xie
Maintainer: Haitian Xie <xht@gsm.pku.edu.cn>
Description: Computes Chernoff's distribution based on the method in Piet Groeneboom & Jon A Wellner (2001) Computing Chernoff's Distribution, Journal of Computational and Graphical Statistics, 10:2, 388-400, <doi:10.1198/10618600152627997>. Chernoff's distribution is defined as the distribution of the maximizer of the two-sided Brownian motion minus quadratic drift. That is, Z = argmax (B(t)-t^2).
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.3
Imports: gsl
NeedsCompilation: no
Packaged: 2023-05-28 23:45:32 UTC; haitianxie
Repository: CRAN
Date/Publication: 2023-05-30 10:10:05 UTC

Density function of Chernoff's distribution

Description

Computes the density of Chernoff's distribution.

Usage

dChern(x)

Arguments

x

evaluation point of the density.

Value

The function returns Chernoff's density evaluated at x.

Examples

dChern(0)

Cumulative distribution function of Chernoff's distribution

Description

Computes the CDF of Chernoff's distribution.

Usage

pChern(q)

Arguments

q

evaluation point of the distribution function.

Value

The function returns Chernoff's distribution function evaluated at q.

Examples

pChern(0)

Quantile function of Chernoff's distribution

Description

Computes the quantiles of Chernoff's distribution.

Usage

qChern(p)

Arguments

p

evaluation point of the quantile function.

Value

The function returns Chernoff's quantile function evaluated at p.

Examples

qChern(0.5)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.